load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/shea_util.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/Nicolas.ncl"
load "../tbtest.ncl"
;------------------------------------------------------------------------------------------------------------------------------------------------------

begin

  STEST="ttest" ; Name of the statistical test
  
  ; Data directory
  dirin="./"
  
  ; Air temperature anomalies
  ft=addfile(dirin+"Anomalies_tas.nc","r")
  lon=ft->lon(:)
  lat=ft->lat(:) 
  tinte=ft->anomT(:,:,:)
  tinte&lon=lon
  tinte&lat=lat 
  tMinte=ft->feMean 
  tSinte=ft->stdMean
  stdTinte=ft->stdT

  ; Meridional wind
  fv=addfile(dirin+"Anomalies_vas.nc","r") 
  vinte=fv->anomT(:,:,:)
  vinte&lon=lon
  vinte&lat=lat
  vMinte=fv->feMean
  vSinte=fv->stdMean
  stdVinte=fv->stdT

  ; Zonal wind
  fu=addfile(dirin+"Anomalies_uas.nc","r") 
  uinte=fu->anomT(:,:,:)
  uinte&lon=lon
  uinte&lat=lat
  uMinte=fu->feMean
  uSinte=fu->stdMean
  stdUinte=fu->stdT

  ; ------------------------------------------ Statistical test
  number=uinte@number
  ntotal=sum(number)
  statsT=new(dimsizes(tinte),float)
  statsU=new(dimsizes(uinte),float)
  statsV=new(dimsizes(vinte),float)
  do indcl=0,3
    if STEST.eq."TB"   
      print("terray bro")
      statsT(:,:,indcl)=tbtest(tMinte, tSinte,ntotal,tinte(:,:,indcl),stdTinte(:,:,indcl),number(indcl))
      statsU(:,:,indcl)=tbtest(uMinte, uSinte,ntotal,uinte(:,:,indcl),stdUinte(:,:,indcl),number(indcl))
      statsV(:,:,indcl)=tbtest(vMinte, vSinte,ntotal,vinte(:,:,indcl),stdVinte(:,:,indcl),number(indcl))
    else
      print("ttest")
      statsT(:,:,indcl)=ttest(tMinte, tSinte*tSinte,ntotal,tinte(:,:,indcl),stdTinte(:,:,indcl)*stdTinte(:,:,indcl),number(indcl),True,False)
      statsU(:,:,indcl)=ttest(uMinte, uSinte*uSinte,ntotal,uinte(:,:,indcl),stdUinte(:,:,indcl)*stdUinte(:,:,indcl),number(indcl),True,False)
      statsV(:,:,indcl)=ttest(vMinte, vSinte*vSinte,ntotal,vinte(:,:,indcl),stdVinte(:,:,indcl)*stdVinte(:,:,indcl),number(indcl),True,False)
    end if
  end do

  mean=0
  sd=1
  coef=0.95 
  if STEST.eq."TB" 
    print("terray bro") ; Student test of the Terray brothers (Laurent and Pascal)
    PT = cdfnor_p(abs(statsT),(conform(statsT,mean,-1)),conform(statsT,sd,-1))
    PU = cdfnor_p(abs(statsU),(conform(statsU,mean,-1)),conform(statsU,sd,-1))
    PV = cdfnor_p(abs(statsV),(conform(statsV,mean,-1)),conform(statsV,sd,-1))
  else
    print("ttest") ; Student test 
    PT=1-statsT
    PU=1-statsU
    PV=1-statsV
  end if
    
  ; Land sea-mask
  a    = addfile("$NCARG_ROOT/lib/ncarg/data/cdf/landsea.nc","r")
  lsdata = a->LSMASK
  lsm  = landsea_mask(lsdata,uinte&lat,uinte&lon)
  lsmC=conform(tinte,lsm,(/0,1/))
  t=tinte
  u = mask(uinte,lsmC.ge.1,False)
  v = mask(vinte,lsmC.ge.1,False)
  
  ; Mask the missing values
  t = mask(t,abs(PT).le.coef,False)
  u = mask(u,abs(PU).le.coef.and.abs(PV).le.coef,False)
  v = mask(v,abs(PU).le.coef.and.abs(PV).le.coef,False)  
    
  copy_VarCoords(uinte,u)
  copy_VarCoords(vinte,v)
  copy_VarCoords(tinte,t)
  copy_VarCoords(tinte,PT)

  tf=(t(cluster|:,lat|:,lon|:))
  uf=(u(cluster|:,lat|:,lon|:))
  vf=(v(cluster|:,lat|:,lon|:))
  ptf=(PT(cluster|:,lat|:,lon|:))

  ;****************************************************************************************** Trace
  clnames=(/"AR","BLK","NAO-","NAO+"/)

  m=-3
  M=-m
  ecart=0.5
  n=floattointeger((M-m)/ecart)
  levels=fspan(m,M,n+1)

  wks=gsn_open_wks("pdf",get_script_prefix_name())     ;Ouverture du WKS
  gsn_define_colormap(wks,"cmp_b2r")
  g=0.7
  newindex=NhlNewColor(wks,g,g,g)
 
  plotF=new(4,graphic)

  ; -------------------------------------------------------------------------------- Ressources contour plot
  res=True
  res@gsnFrame=False
  res@gsnDraw = False
  res@gsnAddCyclic = False
  res@mpLimitMode            = "LatLon"
  res@gsnMaskLambertConformal = True
  res@mpProjection="LambertConformal"
  res@mpMinLatF=20
  res@mpMaxLatF=80
  res@mpMinLonF=-80
  res@mpMaxLonF=30
  res@mpCenterLonF           = -40
  res@mpCenterLatF           = 45
  res@gsnMajorLatSpacing=10
  res@gsnMajorLonSpacing=10
  res@gsnLeftString=""
  res@gsnRightString=""
  res@cnFillBackgroundColor=1
  res@mpFillOn               = True
  res@mpLandFillColor        = newindex
  res@mpLimitMode            = "LatLon"
  res@mpOutlineOn            = True        ; turn on continental outlines
  res@mpOutlineDrawOrder     = "PostDraw"      ; draw continental outline last
  res@mpGridAndLimbOn        =  True
  res@mpGridLineDashPattern      = 2           ; make lat/lon lines dash
  res@mpGridLatSpacingF = 10
  res@mpGridLonSpacingF = 10
  res@cnFillDrawOrder="PreDraw"
  res@cnFillMode="CellFill" 
  res@sfXArray = tf&lon
  res@sfYArray = tf&lat
  res@cnFillOn            = True
  res@cnLinesOn           = False         ; Turn lines off
  res@cnLineLabelsOn      = False         ; Turn labels off
  res@cnLevelSelectionMode = "ExplicitLevels"
  res@cnLevels=levels
  res@gsnSpreadColors       = True         ; use full colormap
  res@gsnSpreadColorStart   = 2           ; start at color 10
  res@gsnSpreadColorEnd     =65        ; end at color 185
  res@lbLabelBarOn = False
  res@gsnCenterStringFontHeightF=0.017
  
  ;-------------------------------------------------------------------------------- Ressources stippling
  res2=True
  res2@gsnFrame=False
  res2@gsnDraw=False
  res2@cnFillBackgroundColor=-1
  res2@cnLevelSelectionMode = "ExplicitLevels"
  res2@cnLevels=(/coef/)
  res2@cnLinesOn=False
  res2@cnFillOn=True
  res2@cnFillPattern=17
  res2@lbLabelBarOn=False
  res2@sfXArray=tf&lon
  res2@sfYArray=tf&lat
  res2@cnFillColors=(/newindex,-1/)
  res2@gsnAddCyclic=False
  res2@cnInfoLabelOn=False
  res2@cnLineLabelsOn=False
  res2@cnFillDrawOrder="PreDraw"
  
  ; -------------------------------------------------------------------------------- Ressources vector plot
  resV=True
  resV@gsnFrame=False
  resV@gsnDraw = False
  resV@vfXArray = uf&lon
  resV@vfYArray = uf&lat
  resV@vcRefMagnitudeF         = 5             ; make vectors larger
  resV@vcRefLengthF            = 0.050           ; ref vec length
  resV@vcGlyphStyle            = "CurlyVector"    ; turn on curly vectors
  resV@vcMinDistanceF          = 0.020           ; thin out vectors
  resV@vcMinFracLengthF        = 0.0
  resV@vcLineArrowThicknessF = 2

  do indCl=0,3
    
    if(indCl.eq.0)
      resV@vcRefAnnoString1 ="Wind anomalies~C~        ("+refmag +"m/s)" ; Ecriture Legende dans le label
      resV@vcRefAnnoFontHeightF = 0.015 ; Augmente la taille du Label.
      resV@vcRefAnnoOn=True
      resV@vcRefAnnoString2On = False
      resV@vcRefAnnoOrthogonalPosF   = -0.5;-0.95 
      resV@vcRefAnnoParallelPosF   = 0.9
      resV@vcRefAnnoPerimSpaceF=0.33
      resV@vcRefAnnoArrowSpaceF=0.7
    end if
    
    if(indCl.ne.0) then
      resV@vcRefAnnoOn=False
    end if

    if(indCl.eq.0)  
      res@tmXBLabelsOn=False
      res@tmYLLabelsOn=True
    else if(indCl.eq.1) 
      res@tmXBLabelsOn=False
      res@tmYLLabelsOn=False     
    else if(indCl.eq.2) 
      res@tmXBLabelsOn=True
      res@tmYLLabelsOn=True
    else
      res@tmXBLabelsOn=True
      res@tmYLLabelsOn=False
    end if
    end if
    end if

    indClok=indCl+1
    res@gsnCenterString=clnames(indCl)
    plott= gsn_csm_contour_map(wks,tf(indCl,:,:),res)
    plotu = gsn_csm_vector(wks,uf(indCl,:,:),vf(indCl,:,:),resV)
    plotbis=gsn_csm_contour(wks,PT(:,:,indCl),res2)
    overlay(plott,plotbis)
    overlay(plott,plotu)
    
    plotF(indCl)=plott
    
  end do

  ; -------------------------------------------------------------------------------- Ressources panelling
  resP=True
  resP@gsnPanelLabelBar = True                   ; add common colorbar
  resP@lbLabelStride=2
  resP@lbTitleString ="Air-temperature anomalies (K)"
  resP@lbTitlePosition="Bottom"
  resP@lbLabelFontHeightF=0.013
  resP@lbTitleFontHeightF=0.015
  resP@pmLabelBarOrthogonalPosF=-0.015
  resP@amOrthogonalPosF =0.4
  resP@amParallelPosF =0.2
  resP@gsnPanelFigureStringsFontHeightF =0.015
  resP@gsnPanelYWhiteSpacePercent=2
  resP@gsnPanelXWhiteSpacePercent=0
  resP@gsnPanelFigureStrings = (/"a)","b)","c)","d)"/)

  gsn_panel(wks,plotF,(/2,2/),resP)               ; now draw as one plot

  ;gsn_draw_colormap(wks)
  
end
